summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/timeperiod.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/timeperiod.h')
-rw-r--r--kalarm/lib/timeperiod.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kalarm/lib/timeperiod.h b/kalarm/lib/timeperiod.h
index 86b66379..9c4152b7 100644
--- a/kalarm/lib/timeperiod.h
+++ b/kalarm/lib/timeperiod.h
@@ -65,10 +65,10 @@ class TimePeriod : public TQHBox
* being allowed as units; only days and weeks can ever be used,
* regardless of other method calls. Set true to allow minutes,
* hours/minutes, days or weeks as units.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- TimePeriod(bool allowMinute, TQWidget* tqparent, const char* name = 0);
+ TimePeriod(bool allowMinute, TQWidget* parent, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the widget is read-only for the user. If read-only,
@@ -65,10 +65,10 @@ class TimePeriod : public TQHBox
* regardless of other method calls. Set true to allow minutes,
* hours/minutes, days or weeks as units.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/